@@ -6,7 +6,7 @@
 #' label representing a bounding area such as a city.
 #'
 #' @export
-#' 
+#'
 #' @template location
 #' @return A list containing metadata and the data, or a single data.frame.
 #' @examples \dontrun{
@@ -34,7 +34,7 @@ ncdc_locs_cats <- function(datasetid=NULL, locationcategoryid=NULL,
   args <- noaa_compact(list(datasetid=datasetid,locationcategoryid=locationcategoryid,
     startdate=startdate, enddate=enddate,token=token,sortfield=sortfield,
     sortorder=sortorder,limit=limit,offset=offset))
-
+  if (length(args) == 0) args <- NULL
   temp <- GET(url, query=args, add_headers("token" = token), ...)
   tt <- check_response(temp)
   if(is(tt, "character")){
@@ -45,7 +45,7 @@ ncdc_locs_cats <- function(datasetid=NULL, locationcategoryid=NULL,
       all <- list(meta=NULL, data=dat)
     } else
     {
-      dat <- do.call(rbind.fill, lapply(tt$results, function(x) data.frame(x,stringsAsFactors=FALSE)))
+      dat <- dplyr::bind_rows(lapply(tt$results, function(x) data.frame(x,stringsAsFactors=FALSE)))
       meta <- tt$metadata$resultset
       atts <- list(totalCount=meta$count, pageCount=meta$limit, offset=meta$offset)
       all <- list(meta=atts, data=dat)
